﻿using UnityEngine;
using System.Collections;

public class BadGuyScript : Shootable {

	public float gravity = 20.0F;

	public Transform target;

	public Transform visibleModel;

	private CharacterController controller;
	private NavMeshAgent agent;

	public float score;

	public float shootDelay;
	private float shootDelayStart;
	private bool freshBlood;

	public Transform remains;
	public Vector3 remainsRotation;
	public float remainsY;

	private bool dead;

	private StandardArmamentTraining arms;

	public Transform tombstoneParent;

	public Transform dieSound;

	// Use this for initialization
	void Start () {
		controller = this.GetComponent<CharacterController>();
		if (controller == null) print (this.name + " expected a CharacterController but couldn't find one!");

		agent = this.GetComponent<NavMeshAgent>();
		if (agent == null) print (this.name + " expected a NavMeshAgent but couldn't find one!");

		arms = this.GetComponent<StandardArmamentTraining>();
		if (arms == null) print (this.name + " expected a StandardArmamentTraining but couldn't find one!");

		tombstoneParent = GameObject.Find("TombstoneParent").transform;
		if(tombstoneParent == null) print (this.name + " couldn't find an object called TombstoneParent");

		dead = false;
		freshBlood = false;
	}
	
	// Update is called once per frame
	void Update () {
		if(!GameManager.isPaused()){
			Vector3 moveDirection = Vector3.zero;
			moveDirection.y -= gravity * Time.deltaTime;
			controller.Move(moveDirection * Time.deltaTime);

			agent.SetDestination(target.position);

			//print(visibleModel.eulerAngles.y);
			visibleModel.LookAt(new Vector3(target.position.x, visibleModel.position.y, target.position.z));
			//restrict facing to certain angles
			if(visibleModel.eulerAngles.y > 135 && visibleModel.eulerAngles.y <= 225){
				visibleModel.eulerAngles = new Vector3(visibleModel.eulerAngles.x, 180, visibleModel.eulerAngles.z);
			} else if(visibleModel.eulerAngles.y > 225 && visibleModel.eulerAngles.y <= 315){
				visibleModel.eulerAngles = new Vector3(visibleModel.eulerAngles.x, 270, visibleModel.eulerAngles.z);
			} else if(visibleModel.eulerAngles.y > 315 || visibleModel.eulerAngles.y <= 45){
				visibleModel.eulerAngles = new Vector3(visibleModel.eulerAngles.x, 0, visibleModel.eulerAngles.z);
			} else if(visibleModel.eulerAngles.y > 45 && visibleModel.eulerAngles.y <= 135){
				visibleModel.eulerAngles = new Vector3(visibleModel.eulerAngles.x, 90, visibleModel.eulerAngles.z);
			}

			//if someone's in range, shoot
			if(arms.numTargetsInRange() > 0){
				if(!freshBlood){
					freshBlood = true;
					shootDelayStart = Time.time;
				} else if(Time.time > shootDelayStart + shootDelay){
					arms.fire ();
				}
			} else {
				freshBlood = false;
			}
		}
	}

	public override void getShot(){
		if(dead) return;
		if(dieSound != null){
			Instantiate(dieSound, transform.position, transform.rotation);
		}
		Transform tombstone = (Transform) Instantiate(remains, new Vector3(transform.position.x, remainsY, transform.position.z), Quaternion.Euler(remainsRotation));
		tombstone.parent = tombstoneParent;
		GameManager.changeScore(score);
		GameManager.player.GetComponent<PlayerScript>().removeTarget(this.transform);
		Destroy (this.gameObject);
		dead = true;
	}
}
