﻿using UnityEngine;
using System.Collections;

public class PlayerScript : Shootable {

	public float moveSpeed, gravity = 20.0F;

	public float healthLossWhenShot = 5;

	public Transform visibleModel;

	private CharacterController controller;

	private StandardArmamentTraining arms;

	public Transform hurtSound;

	// Use this for initialization
	void Start () {
		controller = this.GetComponent<CharacterController>();
		if (controller == null) print (this.name + " expected a CharacterController but couldn't find one!");

		arms = this.GetComponent<StandardArmamentTraining>();
		if (arms == null) print (this.name + " expected a StandardArmamentTraining but couldn't find one!");
	}
	
	// Update is called once per frame
	void Update () {
		if(!GameManager.isPaused()){
			//if we're moving, call move()
			//if(Input.GetAxis("Horizontal") != 0 || Input.GetAxis("Vertical") != 0) move ();
			move ();

			//see if somebody's firing
			if(Input.GetButtonDown("Fire")){
				//print ("fire");
				arms.fire();
			}
		}
	}

	void FixedUpdate(){

	}

	private void move(){
		//use local variables so i don't have to call them twenty times
		float hor = -Input.GetAxis("Horizontal"), vert = Input.GetAxis("Vertical");
		//do the actual movement
		//transform.Translate(vert * Time.deltaTime * moveSpeed, 0, hor * Time.deltaTime * moveSpeed);
		//controller.Move(new Vector3(vert * Time.deltaTime * moveSpeed, 0, hor * Time.deltaTime * moveSpeed));
		Vector3 moveDirection = new Vector3(vert, 0, hor);
		moveDirection *= moveSpeed;
		moveDirection.y -= gravity * Time.deltaTime;
		controller.Move(moveDirection * Time.deltaTime);
		//print (controller.isGrounded);

		//now we're rotating to face the right way
		if(Mathf.Abs(vert) == Mathf.Abs(hor)){ //if they're both maxed out, how the hell am i supposed to decide?
		} else if (Mathf.Abs(hor) > Mathf.Abs(vert)) { //if horizontal movement greater than vertical
			visibleModel.transform.eulerAngles = new Vector3(0, hor < 0 ? 0 : 180, 0);
		} else { //vert being greater is the only option left, if they were both zero we wouldn't be here
			visibleModel.transform.eulerAngles = new Vector3(0, vert < 0 ? 90 : 270, 0);
		}
	}

	public override void getShot(){
		GameManager.changeHealth(-healthLossWhenShot);
		if(hurtSound != null) Instantiate(hurtSound, transform.position, transform.rotation);
	}

	public void removeTarget(Transform target){
		arms.removeTarget(target);
	}
}
